# Self-Built Software Discovery API: Asynchronous Processing of SBOM File Ingestions (April 7, 2025)
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/api-updates-sbom-async-processing#overview)
  * [Background](https://help.sap.com/docs/leanix/ea/api-updates-sbom-async-processing#background)
  * [What’s Changing](https://help.sap.com/docs/leanix/ea/api-updates-sbom-async-processing#what%E2%80%99s-changing)
  * [Response Status Code](https://help.sap.com/docs/leanix/ea/api-updates-sbom-async-processing#response-status-code)
  * [Enhanced Response Payload](https://help.sap.com/docs/leanix/ea/api-updates-sbom-async-processing#enhanced-response-payload)
  * [New Endpoint for Tracking the Job Status](https://help.sap.com/docs/leanix/ea/api-updates-sbom-async-processing#new-endpoint-for-tracking-the-job-status)
  * [What You Need to Do](https://help.sap.com/docs/leanix/ea/api-updates-sbom-async-processing#what-you-need-to-do)
  * [Test the New API Behavior During the Transition Period](https://help.sap.com/docs/leanix/ea/api-updates-sbom-async-processing#test-the-new-api-behavior-during-the-transition-period)


Learn what’s changing in the Self-Built Software Discovery API and how to prepare for these changes to avoid any issues with your integrations.
